<!DOCTYPE html>
<html lang="en">

<head>

  <title>{{ page.title }} | {{ site.title }}</title>

  <!-- favicon -->
  <link rel="icon" type="image/png" href="{{ site.baseurl }}/favicon.png">

  <!-- CSS files -->
  <link rel="stylesheet" href="{{ site.baseurl }}/_sass/main.css">

</head>

<body>

  {% include header.html %}

  <main>
    {{ content }}
  </main>

  {% include footer.html %}

  <!-- JS files -->
  <script src="{{ site.baseurl }}/scripts/header.js"></script>

</body>

</html>